@@ -1,6 +1,6 @@
 import os
 import logging
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 import requests
 import pandas as pd
@@ -80,28 +80,6 @@ class Client:
             paths.append(path)
         return paths
 
-    def select_submission(self, submission_id: int) -> None:
-        """Select a submission.
-
-        Args:
-            submission_id (int): ID of the submission to be selected
-
-        Example:
-            >>> client = crunchdao.Client()
-            >>> submission_id = client.upload(...)
-            >>> client.select_submission(submission_id)
-            Submission selected.
-        """
-        response = requests.patch(
-            f"{BASE_URL}/v2/submissions/{submission_id}",
-            json={"selected": True},
-            params={"apiKey": self.apikey})
-        if response.status_code == 200:
-            logger.info("Submission selected.")
-        else:
-            logger.error("Selecting submission failed")
-            logger.error(response.content)
-
     def set_comment(self, submission_id: int, comment: str) -> None:
         """Set comment of a submission
 
@@ -125,7 +103,7 @@ class Client:
             logger.error("setting comment failed")
             logger.error(response.content)
 
-    def upload(self, predictions: pd.DataFrame) -> int:
+    def upload(self, predictions: pd.DataFrame) -> Optional[int]:
         """Upload predictions to the tournament
 
         Args:
@@ -146,6 +124,8 @@ class Client:
 
         if response.status_code == 200:
             logger.info("Submission submitted :)")
+            submission_id = response.json()["id"]
+            return submission_id
         elif response.status_code == 423:
             logger.error("Submissions are close")
             logger.info("You can only submit during rounds eg: "
@@ -165,6 +145,9 @@ class Client:
         elif response.status_code == 401:
             logger.error("Your email hasn't been verified")
             logger.info("Please verify your email or contact a cruncher.")
+        elif response.status_code == 403:
+            logger.error("Access Denied")
+            logger.info("Please setup your API_KEY.")
         elif response.status_code == 409:
             logger.error("Duplicate submission")
             logger.info("Your work has already been submitted with the exact "
@@ -179,8 +162,6 @@ class Client:
             logger.info("Ouch! It seems that we were not expecting this kind "
                         "of result from the server, if the probleme persist, "
                         "contact a cruncher.")
-        submission_id = response.json()["id"]
-        return submission_id
 
     def submissions(self, user_id: int = None,
                     round_num: int = None) -> pd.DataFrame:
@@ -196,34 +177,16 @@ class Client:
                 * user_id (`int`)
                 * username (`str`)
                 * deleted (`bool`)
-                * role (`str`)
-                * crunch_number (`int`)
-                * crunch_ts (`datetime`)
-                * round_id (`int`)
-                * final_crunch (`str`)
+                * administrator (`bool`)
+                * status (`str`)
                 * upload_ts (`datetime`)
                 * eval_ts (`datetime`)
-                * selected (`bool`)
-                * selected_by (`str`)
                 * comment (`str`)
+                * message (`str`)
+                * trace (`str`)
                 * file_hash (`str`)
                 * file_name (`str`)
-                * chosen (`bool`)
-                * private_success (`bool`)
-                * private_r (`float`)
-                * private_g (`float`)
-                * private_b (`float`)
-                * private_mean (`float`)
-                * private_message (`str`)
-                * private_originality (`float`)
-                * private_arena_score (`float`)
-                * public_success (`bool`)
-                * public_r (`float`)
-                * public_g (`float`)
-                * public_b (`float`)
-                * public_mean (`float`)
-                * public_message (`str`)
-                * public_originality (`float`)
+                * file_length (`int`)
 
         Example:
             >>> crunchdao.Client().submissions(round_num=89)
@@ -240,25 +203,19 @@ class Client:
             params["round"] = round_num
         data = self.raw_request(url, params, authorization=authorization)
 
-        private = pd.DataFrame([item["private"] for item in data
-                                if "private" in item])
-        private.columns = ["private_" + col for col in private.columns]
-
-        public = pd.DataFrame([item["public"] for item in data])
-        public.columns = ["public_" + col for col in public.columns]
         user = pd.DataFrame([item["user"] for item in data])
         user.rename(columns={"id": "user_id"}, inplace=True)
-        crunch = pd.DataFrame([item["crunch"] for item in data])
-        crunch.rename(columns={"number": "crunch_number",
-                               "final": "final_crunch",
-                               "at": "crunch_ts"}, inplace=True)
-        crunch.drop("id", inplace=True, axis=1)
+
+        file_meta = pd.DataFrame([item["fileMetadata"] for item in data])
+        columns = {col: "file_" + col for col in file_meta}
+        file_meta.rename(columns=columns, inplace=True)
+
         general = pd.DataFrame.from_dict(data)
         general.rename(columns={"uploadedAt": "upload_ts",
                                 "evaluatedAt": "eval_ts"}, inplace=True)
-        general.drop(["user", "crunch", "private", "public", "userId"],
+        general.drop(["user", "userId", "fileMetadata"],
                      axis=1, inplace=True, errors="ignore")
-        df = pd.concat([user, crunch, general, private, public], axis=1)
+        df = pd.concat([user, general, file_meta], axis=1)
         df.set_index("id", inplace=True)
 
         # convert CamelCase to snake_case
@@ -312,20 +269,6 @@ class Client:
                    for key, val in data.items()}
         return cleaned
 
-    def last_crunch(self) -> int:
-        """Get the crunch number of the last crunch you uploaded to this round
-
-        Returns:
-            int
-
-        Example:
-            >>> crunchdao.Client().last_crunch()
-            42
-        """
-        current_round = self.dataset_config()["round_id"]
-        subs = self.submissions(round_num=current_round)
-        return subs["crunch_number"].max()
-
 
 if __name__ == "__main__":
     client = Client()
